..  This file is part of kwalitee
    Copyright (C) 2014, 2015 CERN.

    kwalitee is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    kwalitee is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with kwalitee; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.

    In applying this licence, CERN does not waive the privileges and immunities
    granted to it by virtue of its status as an Intergovernmental Organization
    or submit itself to any jurisdiction.

:orphan:

=========
 Aliases
=========

Those elements are badly resolved by :py:mod:`sphinx.ext.intersphinx`, so we
had to create local references here.


.. py:class:: builtins.object
              object

    Base class of any classes: ``object``

    .. seealso::

        - `New-style Classes <https://www.python.org/doc/newstyle/>`_
        - `New-style and classic classes
          <https://docs.python.org/2/reference/datamodel.html#new-style-and-classic-classes>`_

.. py:class:: flask_sqlalchemy.Model

   Flask SQLAlchemy model: :py:class:`flask_sqlalchemy.Model`

.. py:class:: werkzeug.routing.BaseConverter

    Werkzeug base converter.

    .. seealso:: Werkzeug URL Routing: :py:mod:`werkzeug.routing`
